@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import os
 from tryton.config import get_config_dir
 
@@ -22,18 +22,21 @@ class Fingerprints(dict):
                     host, sha1 = line.split(' ')
                 except ValueError:
                     host, sha1 = line, ''
-                self[host] = sha1
+                # Skip current implementation to avoid save
+                dict.__setitem__(self, host, sha1)
 
     def save(self):
         with open(KNOWN_HOSTS_PATH, 'w') as known_hosts:
             known_hosts.writelines('%s %s' % (host, sha1)
-                    + os.linesep for host, sha1 in self.iteritems())
+                    + os.linesep for host, sha1 in self.items())
 
     def __setitem__(self, key, value):
-        assert isinstance(key, basestring)
+        assert isinstance(key, str)
         if value:
             assert len(value) == 59  # len of formated sha1
         else:
             value = ''
+        changed = value != self.get(key)
         super(Fingerprints, self).__setitem__(key, value)
-        self.save()
+        if changed:
+            self.save()
