@@ -508,7 +508,12 @@ class Form(SignalEvent, TabContent):
             if value == 'ok':
                 return self.sig_save(None)
             if value == 'ko':
-                return self.sig_reload(test_modified=False)
+                record_id = self.screen.current_record.id
+                if self.sig_reload(test_modified=False):
+                    if self.screen.current_record:
+                        return record_id == self.screen.current_record.id
+                    elif record_id < 0:
+                        return True
             return False
         return True
 
