@@ -91,6 +91,7 @@ class Group(SignalEvent, list):
 
     def insert(self, pos, record):
         assert record.group is self
+        pos = min(pos, len(self))
         if pos >= 1:
             self.__getitem__(pos - 1).next[id(self)] = record
         if pos < self.__len__():
@@ -182,6 +183,7 @@ class Group(SignalEvent, list):
         ctx['_timestamp'] = {}
         for rec in records:
             ctx['_timestamp'].update(rec.get_timestamp())
+            rec.destroy()
         record_ids = set(r.id for r in records)
         reload_ids = set(root_group.on_write_ids(list(record_ids)))
         reload_ids -= record_ids
